@@ -8,13 +8,11 @@ import requests
 import pandas as pd
 from time import sleep
 from tempfile import gettempdir
+from http.client import responses
 from urllib import parse, request
 from datetime import datetime
 from functools import partial
 
-class futures:
-    pass
-
 class DataClient:
     """
     支持类型：
@@ -194,7 +192,16 @@ class DataClient:
     def quantdata(self, method, **rest):
         post_data = {"method": method, **rest}
         res = requests.post(self.quant_url, headers={"token": self.token}, json=post_data)
-        return pd.read_json(res.content.decode("utf-8"), orient="split")
+        if res.status_code == 200:
+            json_data = res.content.decode("utf-8")
+            try:
+                return pd.read_json(json_data, orient="split")
+            except Exception as e:
+                print(e)
+        else:
+            print("ERROR:", responses[res.status_code])
+        return pd.DataFrame()
+
 
     def status_check(self):
         while True:
